@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::InsertCodeOutput;
 
-our $DATE = '2015-01-25'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2015-05-05'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
@@ -17,7 +17,7 @@ with (
     },
 );
 
-has verbatim => (is => 'rw', default => sub{1});
+has make_verbatim => (is => 'rw', default => sub{1});
 
 use namespace::autoclean;
 
@@ -49,7 +49,7 @@ sub _code_output {
         die "eval '$code' failed: $@";
     }
 
-    $merged =~ s/^/ /gm if $self->verbatim;
+    $merged =~ s/^/ /gm if $self->make_verbatim;
     $merged;
 }
 
@@ -69,14 +69,14 @@ Dist::Zilla::Plugin::InsertCodeOutput - Insert the output of Perl code into your
 
 =head1 VERSION
 
-This document describes version 0.02 of Dist::Zilla::Plugin::InsertCodeOutput (from Perl distribution Dist-Zilla-Plugin-InsertCodeOutput), released on 2015-01-25.
+This document describes version 0.03 of Dist::Zilla::Plugin::InsertCodeOutput (from Perl distribution Dist-Zilla-Plugin-InsertCodeOutput), released on 2015-05-05.
 
 =head1 SYNOPSIS
 
 In dist.ini:
 
  [InsertCodeOutput]
- ;verbatim=1
+ ;make_verbatim=1
 
 In your POD:
 
@@ -88,7 +88,7 @@ This module finds C<# CODE: ...> directives in your POD, evals the specified
 Perl code while capturing the output using L<Capture::Tiny>'s C<capture_merged>
 (which means STDOUT and STDERR output are both captured), and insert the output
 to your POD as verbatim paragraph (indented with a whitespace), unless when
-C<verbatim> is set to 0 then it is inserted as-is. If eval fails (C<$@> is
+C<make_verbatim> is set to 0 then it is inserted as-is. If eval fails (C<$@> is
 true), build will be aborted.
 
 =for Pod::Coverage .+
